==> process-kafka-multi-springboot-1.11.0.Final-sources.jar: defaultPackage/RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0.java <==
package defaultPackage;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.acme.travel.Traveller;
import static defaultPackage.RulesE5717FD31E01E6A14765D39787C99F47.*;

public class RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0 {

    /**
     * Rule name: Process travellers
     */
    public static org.drools.model.Rule rule_Process_32travellers() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Process travellers").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                            "travellers")
                                                                 .build(D.pattern(var_$traveller).expr("GENERATED_1431ED0539270BF7254590AD8439205F",
                                                                                                       defaultPackage.PC0.LambdaPredicateC07B59EDD69521AB35FF7BAA2F677E41.INSTANCE,
                                                                                                       D.alphaIndexedBy(boolean.class,
                                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                        DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                        defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                        false),
                                                                                                       D.reactOn("processed")).expr("GENERATED_7A4D786786CA592335131B19292DCAA2",
                                                                                                                                    defaultPackage.P24.LambdaPredicate24EE6DA99999E4A1CA1F4FB1FA67D7C4.INSTANCE,
                                                                                                                                    D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                     org.drools.model.Index.ConstraintType.NOT_EQUAL,
                                                                                                                                                     DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                     defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                     "American"),
                                                                                                                                    D.reactOn("nationality")),
                                                                        D.on(var_$traveller).execute(defaultPackage.PDB.LambdaConsequenceDB15E1BAB4340CF37CDDB3E94958C4C7.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Don't process travellers from US
     */
    public static org.drools.model.Rule rule_Don_39t_32process_32travellers_32from_32US() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Don't process travellers from US").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                                          "travellers")
                                                                               .build(D.pattern(var_$traveller).expr("GENERATED_1431ED0539270BF7254590AD8439205F",
                                                                                                                     defaultPackage.PC0.LambdaPredicateC07B59EDD69521AB35FF7BAA2F677E41.INSTANCE,
                                                                                                                     D.alphaIndexedBy(boolean.class,
                                                                                                                                      org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                      DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                                      defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                                      false),
                                                                                                                     D.reactOn("processed")).expr("GENERATED_68191149A3CDE5A95B4E42CAFC6EA789",
                                                                                                                                                  defaultPackage.PE9.LambdaPredicateE98F2154E83C8EBD16ADD612242E158D.INSTANCE,
                                                                                                                                                  D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                                   org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                                                   DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                                   defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                                   "American"),
                                                                                                                                                  D.reactOn("nationality")),
                                                                                      D.on(var_$traveller).execute(defaultPackage.PB3.LambdaConsequenceB3D22D4EF8725C47598CE06CE4DF27F0.INSTANCE));
        return rule;
    }
}

==> process-kafka-multi-springboot-1.12.0.Final-sources.jar: defaultPackage/RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0.java <==
package defaultPackage;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.acme.travel.Traveller;
import static defaultPackage.RulesE5717FD31E01E6A14765D39787C99F47.*;

public class RulesE5717FD31E01E6A14765D39787C99F47RuleMethods0 {

    /**
     * Rule name: Process travellers
     */
    public static org.drools.model.Rule rule_Process_32travellers() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Process travellers").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                            "travellers")
                                                                 .build(D.pattern(var_$traveller).expr("GENERATED_1431ED0539270BF7254590AD8439205F",
                                                                                                       defaultPackage.P45.LambdaPredicate45C93A9E8FB6C6A7CF276337543C7FE5.INSTANCE,
                                                                                                       D.alphaIndexedBy(boolean.class,
                                                                                                                        org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                        DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                        defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                        false),
                                                                                                       D.reactOn("processed")).expr("GENERATED_7A4D786786CA592335131B19292DCAA2",
                                                                                                                                    defaultPackage.PD5.LambdaPredicateD5EF6E71E36CCA6F2848802E649844EE.INSTANCE,
                                                                                                                                    D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                     org.drools.model.Index.ConstraintType.NOT_EQUAL,
                                                                                                                                                     DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                     defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                     "American"),
                                                                                                                                    D.reactOn("nationality")),
                                                                        D.on(var_$traveller).execute(defaultPackage.PDB.LambdaConsequenceDB15E1BAB4340CF37CDDB3E94958C4C7.INSTANCE));
        return rule;
    }

    /**
     * Rule name: Don't process travellers from US
     */
    public static org.drools.model.Rule rule_Don_39t_32process_32travellers_32from_32US() {
        final org.drools.model.Variable<org.acme.travel.Traveller> var_$traveller = D.declarationOf(org.acme.travel.Traveller.class,
                                                                                                    DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE,
                                                                                                    "$traveller");
        org.drools.model.Rule rule = D.rule("defaultPackage",
                                            "Don't process travellers from US").attribute(org.drools.model.Rule.Attribute.RULEFLOW_GROUP,
                                                                                          "travellers")
                                                                               .build(D.pattern(var_$traveller).expr("GENERATED_1431ED0539270BF7254590AD8439205F",
                                                                                                                     defaultPackage.P45.LambdaPredicate45C93A9E8FB6C6A7CF276337543C7FE5.INSTANCE,
                                                                                                                     D.alphaIndexedBy(boolean.class,
                                                                                                                                      org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                      DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("processed"),
                                                                                                                                      defaultPackage.PC1.LambdaExtractorC1A252580125C353F37F603A551FEA9C.INSTANCE,
                                                                                                                                      false),
                                                                                                                     D.reactOn("processed")).expr("GENERATED_68191149A3CDE5A95B4E42CAFC6EA789",
                                                                                                                                                  defaultPackage.P9D.LambdaPredicate9D6C3E78C5E7637E8BAAB56208E74247.INSTANCE,
                                                                                                                                                  D.alphaIndexedBy(java.lang.String.class,
                                                                                                                                                                   org.drools.model.Index.ConstraintType.EQUAL,
                                                                                                                                                                   DomainClassesMetadataE5717FD31E01E6A14765D39787C99F47.org_acme_travel_Traveller_Metadata_INSTANCE.getPropertyIndex("nationality"),
                                                                                                                                                                   defaultPackage.P00.LambdaExtractor0049DA395F3F9D2ED77B939EE34DB9DB.INSTANCE,
                                                                                                                                                                   "American"),
                                                                                                                                                  D.reactOn("nationality")),
                                                                                      D.on(var_$traveller).execute(defaultPackage.PB3.LambdaConsequenceB3D22D4EF8725C47598CE06CE4DF27F0.INSTANCE));
        return rule;
    }
}
